OC.L10N.register(
    "circles",
    {
    "Teams" : "كوماندىلار",
    "You created the team {circle}" : "سىز گۇرۇپپا {circle} قۇردىڭىز",
    "{author} created the team {circle}" : "{author} ئەترەت {circle} قۇردى",
    "You deleted {circle}" : "سىز {circle} ئۆچۈردىڭىز",
    "{author} deleted {circle}" : "{author} ئۆچۈرۈلگەن {circle}",
    "You made {member} join {circle}" : "سىز {member} قوشۇل {circle} قىلدىڭىز",
    "{author} made {member} join {circle}" : "{author} ياسىغان {member} قوشۇل {circle}",
    "You added team {member} as member to {circle}" : "گۇرۇپپا {member} نى ئەزا سۈپىتىدە {circle} گە قوشتىڭىز",
    "{author} added team {member} as member to {circle}" : "{author} گۇرۇپپا {member} ئەزا سۈپىتىدە {circle} قوشۇلدى",
    "You made {member} leave {circle}" : "سىز {member} ئايرىلىش {circle} قىلدىڭىز",
    "{author} made {member} leave {circle}" : "{author} ياسىغان {member} ئايرىلىش {circle}",
    "You removed {member} from {circle}" : "سىز {member} نى {circle} تىن ئۆچۈردىڭىز",
    "{author} removed {member} from {circle}" : "{ئاپتور} چەمبىرەكتىن {ئەزا} چىقىرىلدى",
    "You joined {circle}" : "سىز {circle} كە قوشۇلدىڭىز",
    "{member} joined {circle}" : "{member} قوشۇلدى {circle}",
    "You accepted the invitation to join {circle}" : "{circle} كە قاتنىشىش تەكلىپىنى قوبۇل قىلدىڭىز",
    "{member} accepted the invitation to join {circle}" : "{member} {circle} ىگە قاتنىشىش تەكلىپىنى قوبۇل قىلدى",
    "You added {member} as member to {circle}" : "سىز {member} غا ئەزا سۈپىتىدە {circle} نى قوشتىڭىز",
    "You have been added as member to {circle} by {author}" : "سىز {circle} تەرىپىدىن {author} كە ئەزا سۈپىتىدە قوشۇلدىڭىز",
    "{member} has been added as member to {circle} by {author}" : "{member} {circle} تەرىپىدىن {author} كە ئەزا سۈپىتىدە قوشۇلدى",
    "You added {external} to {circle}" : "سىز {external} {circle} قوشتىڭىز",
    "{external} has been added to {circle} by {author}" : "{external} {circle} كە {author} تەرىپىدىن قوشۇلدى",
    "You accepted {member}'s request to join {circle}" : "سىز {member} {circle} ىگە قاتنىشىش تەلىپىنى قوبۇل قىلدىڭىز",
    "Your request to join {circle} has been accepted by {author}" : "{circle} كە قاتنىشىش تەلىپىڭىز {author} تەرىپىدىن قوبۇل قىلىندى",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} نىڭ {circle} ىگە قاتنىشىش تەلىپى {author} تەرىپىدىن قوبۇل قىلىندى",
    "You left {circle}" : "تىن چىقتىڭىز سىز {circle}",
    "{member} left {circle}" : "{member} سول {circle}",
    "You declined the invitation to join {circle}" : "سىز {circle} كە قاتنىشىش تەكلىپىنى رەت قىلدىڭىز",
    "{member} declined an invitation to join {circle}" : "{member} {circle} كە قاتنىشىش تەكلىپنامىسىنى رەت قىلدى",
    "You cancelled your request to join {circle}" : "{circle} كە قاتنىشىش تەلىپىڭىزنى بىكار قىلدىڭىز",
    "{member} cancelled a request to join {circle}" : "{member} {circle} ىگە قاتنىشىش تەلىپىنى ئەمەلدىن قالدۇردى",
    "You have been removed from {circle} by {author}" : "سىز {circle} تەرىپىدىن {author} تىن چىقىرىۋېتىلدى",
    "{member} has been removed from {circle} by {author}" : "{member} {circle} ىدىن {author} تەرىپىدىن چىقىرىۋېتىلدى",
    "You removed {external} from {circle}" : "سىز {external} نى {circle} تىن چىقىرىۋەتتىڭىز",
    "{external} has been removed from {circle} by {author}" : "{external} {circle} تەرىپىدىن {author} تىن چىقىرىۋېتىلدى",
    "You cancelled {member}'s invitation to join {circle}" : "سىز {member} {circle} ىگە قاتنىشىش تەكلىپىنى بىكار قىلدىڭىز",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle} كە قاتنىشىش تەكلىۋىڭىز {author} تەرىپىدىن ئەمەلدىن قالدۇرۇلدى",
    "{author} cancelled {member}'s invitation to join {circle}" : "{ئاپتور} ئەزانىڭ {چەمبىرىكىگە قاتنىشىش تەكلىپىنى ئەمەلدىن قالدۇردى",
    "You dismissed {member}'s request to join {circle}" : "سىز {member} نىڭ {circle} قاتنىشىش تەلىپىنى رەت قىلدىڭىز",
    "Your request to join {circle} has been dismissed by {author}" : "{circle} قاتنىشىش تەلىپىڭىز {author} تەرىپىدىن رەت قىلىندى",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{ئەزانىڭ {چەمبىرىكىگە قاتنىشىش تەلىپى {ئاپتور تەرىپىدىن رەت قىلىندى",
    "You invited {member} to join {circle}" : "سىز {member} نى {circle} قاتنىشىشقا تەكلىپ قىلدىڭىز",
    "You have been invited to join {circle} by {author}" : "سىز {circle} تەرىپىدىن {author} قاتنىشىشقا تەكلىپ قىلىندى",
    "{member} has been invited to join {circle} by {author}" : "{member} {circle} تەرىپىدىن {author} قاتنىشىشقا تەكلىپ قىلىندى",
    "You changed {member}'s level in {circle} to %1$s" : "سىز {ئەزا} سەۋىيىسىنى {چەمبىرەكتىكى% 1 $ s گە ئۆزگەرتتىڭىز",
    "{author} changed your level in {circle} to %1$s" : "{ئاپتور} سەۋىيىڭىزنى {چەمبىرەكتىكى% 1 $ s گە ئۆزگەرتتى",
    "{author} changed {member}'s level in {circle} to %1$s" : "{ئاپتور} چەمبىرىكىدىكى {ئەزانىڭ دەرىجىسىنى% 1 $ s غا ئۆزگەرتتى",
    "You sent a request to join {circle}" : "سىز {circle} قاتنىشىش ئىلتىماسىنى ئەۋەتتىڭىز",
    "{member} sent a request to join {circle}" : "{member} {circle} قاتنىشىش ئىلتىماسى ئەۋەتتى",
    "You are the new owner of {circle}" : "سىز {circle} يېڭى ئىگىسى",
    "{member} is the new owner of {circle}" : "{member} {circle} يېڭى ئىگىسى",
    "On events happening in a <strong>team</strong> of which you are a member" : "سىز ئەزا بولغان <strong> گۇرۇپپا </ strong> دا يۈز بەرگەن ۋەقەلەر توغرىسىدا",
    "Any important event in a <strong>team</strong> you are moderating" : "سىز رىياسەتچىلىك قىلىۋاتقان <strong> گۇرۇپپا </ strong> دىكى ھەر قانداق مۇھىم پائالىيەت",
    "On global events happening in any <strong>team</strong>" : "ھەر قانداق <strong> گۇرۇپپا </ strong> دا يۈز بېرىۋاتقان دۇنياۋى ئىشلار توغرىسىدا",
    "Single" : "بويتاق",
    "Personal" : "شەخسىي",
    "System" : "سىستېما",
    "Visible" : "كۆرگىلى بولىدۇ",
    "Open" : "ئېچىڭ",
    "Invite" : "تەكلىپ قىلىڭ",
    "Join request" : "تەلەپكە قوشۇلۇڭ",
    "Friends" : "دوستلار",
    "Password protected" : "پارول قوغدالدى",
    "No Owner" : "ئىگىسى يوق",
    "Hidden" : "يۇشۇرۇن",
    "Backend" : "Backend",
    "Local" : "يەرلىك",
    "Root" : "يىلتىز",
    "Team invite" : "گۇرۇپپا تەكلىپ قىلىدۇ",
    "Federated" : "Federated",
    "Mount point" : "تاغ نۇقتىسى",
    "Nextcloud Account" : "Nextcloud ھېساباتى",
    "Nextcloud Group" : "Nextcloud گۇرۇپپىسى",
    "Email address" : "ئېلخەت ئادرېسى",
    "Contact" : "ئالاقىلىشىڭ",
    "Team" : "Team",
    "Nextcloud App" : "Nextcloud App",
    "Member" : "ئەزا",
    "Moderator" : "رىياسەتچى",
    "Admin" : "باشقۇرغۇچى",
    "Owner" : "Owner",
    "%s shared »%s« with you." : "% s ئورتاقلاشتى »% s« سىز بىلەن.",
    "%s shared »%s« with \"%s\"." : "% s ئورتاقلاشتى »% s«% s »بىلەن.",
    "%s on %s" : "% s on% s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1 $ s ئورتاقلاشتى »%2 $ s« سىز بىلەن.\nئۇنى زىيارەت قىلىش ئۈچۈن ئۇلانمىسى بار ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1 $ s ئورتاقلاشتى »%2 $ s« سىز بىلەن. ئۇنى زىيارەت قىلىش ئۈچۈن ئۇلانمىسى بار ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.",
    "Password to access »%1$s« shared to you by %2$s" : "زىيارەت قىلىش پارولى »%1 $ s«%2 $ s بىلەن ئورتاقلاشتى",
    "Password to access »%s«" : "زىيارەت قىلىش پارولى »% s«",
    "It is protected with the following password:" : "ئۇ تۆۋەندىكى پارول بىلەن قوغدىلىدۇ:",
    "%1$s via %2$s" : "%1 $ s ئارقىلىق%2 $ s",
    "Click the button below to open it." : "ئۇنى ئېچىش ئۈچۈن تۆۋەندىكى كۇنۇپكىنى بېسىڭ.",
    "Open »%s«" : "ئېچىڭ »% s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1 $ s سىز بىلەن بىر قانچە ھۆججەتنى ئورتاقلاشتى.\nئۇلارنى زىيارەت قىلىش ئۈچۈن ئۇلىنىش بىلەن ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1 $ s سىز بىلەن بىر قانچە ھۆججەتنى ئورتاقلاشتى. ئۇلارنى زىيارەت قىلىش ئۈچۈن ئۇلىنىش بىلەن ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.",
    "Password to access files shared to you by %1$s" : "سىز بىلەن ئورتاقلاشقان ھۆججەتلەرنى زىيارەت قىلىش پارولى%1 $ s",
    "Password to access files" : "ھۆججەتلەرنى زىيارەت قىلىدىغان پارول",
    "%s shared multiple files with \"%s\"." : "% s كۆپ ھۆججەتلەرنى \"% s\" بىلەن ئورتاقلاشتى.",
    "%s shared multiple files with you." : "% s سىز بىلەن بىر قانچە ھۆججەتنى ئورتاقلاشتى.",
    "Boot up" : "Boot up",
    "Nextcloud Initialization" : "Nextcloud Initialization",
    "Circles App Initialization" : "چەمبەر ئەپلىرىنى قوزغىتىش",
    "Fresh installation status" : "يېڭى ئورنىتىش ھالىتى",
    "Building Local Database" : "يەرلىك ساندان قۇرۇش",
    "Testing Basic Circle Creation" : "ئاساسىي چەمبىرەك قۇرۇشنى سىناق قىلىش",
    "Adding local users and moderators" : "يەرلىك ئىشلەتكۈچىلەر ۋە رىياسەتچىلەر قوشۇلىدۇ",
    "Show all teams" : "بارلىق كوماندىلارنى كۆرسەت",
    "Create a new team" : "يېڭى گۇرۇپپا قۇرۇڭ",
    "Files" : "ھۆججەتلەر",
    "This feature is not available for personal circles" : "بۇ ئىقتىدار شەخسىي چەمبىرەكلەردە ئىشلىتىلمەيدۇ",
    "The team is not federated" : "بۇ كوماندا فېدېراتسىيە ئەمەس",
    "You cannot join this team" : "سىز بۇ كوماندىغا قوشۇلالمايسىز",
    "This member is not a moderator" : "بۇ ئەزا رىياسەتچى ئەمەس",
    "Insufficient privileges" : "ئىمتىياز يېتەرلىك ئەمەس",
    "This member does not exist" : "بۇ ئەزا مەۋجۇت ئەمەس",
    "This member is the owner of the team" : "بۇ ئەزا كوماندىنىڭ ئىگىسى",
    "Level cannot be changed for this type of member" : "بۇ تۈردىكى ئەزالارنىڭ دەرىجىسىنى ئۆزگەرتىشكە بولمايدۇ",
    "You are already a member of this circle" : "سىز ئاللىبۇرۇن بۇ چەمبىرەكنىڭ ئەزاسى",
    "You have been blocked from this circle" : "سىز بۇ چەمبىرەكتىن توسۇۋېلىندىڭىز",
    "The account is already a member of this circle" : "ھېسابات ئاللىقاچان بۇ چەمبىرەكنىڭ ئەزاسى",
    "The account has already been invited into this circle" : "بۇ ھېسابات ئاللىبۇرۇن بۇ چەمبىرەككە تەكلىپ قىلىنغان",
    "%s (Team owned by %s)" : "% s (% s ئىگىدارچىلىقىدىكى گۇرۇپپا)",
    "You are now a member of the Team \"%2$s\"" : "سىز ھازىر «%2 $ s» گۇرۇپپىسىنىڭ ئەزاسى.",
    "You have been invited by %1$s into the Team \"%2$s\"" : "سىز%1 $ s تەرىپىدىن «%2 $ s» گۇرۇپپىسىغا تەكلىپ قىلىندىڭىز",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1 $ s كوماندىغا ئەزا بولۇش ئىلتىماسىنى «%2 $ s» ئەۋەتتى",
    "Accept" : "قوبۇل قىلىڭ",
    "Refuse" : "رەت قىلىش",
    "Leave the team" : "كوماندىدىن ئايرىلغىن",
    "%s" : "% s",
    "Personal team" : "شەخسىي گۇرۇپپا",
    "%s owned by %s" : "% s ئىگىدارچىلىقىدىكى% s",
    "You have no permission to create a new team" : "يېڭى گۇرۇپپا قۇرۇش ھوقۇقىڭىز يوق",
    "%s shared a file with \"%s\"." : "% s ھۆججەتنى \"% s\" بىلەن ئورتاقلاشتى.",
    "%s shared a file with you." : "% s ھۆججەتنى سىز بىلەن ئورتاقلاشتى.",
    "Open %s" : "% S نى ئېچىڭ",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1 $ s بەزى مەزمۇنلارنى سىز بىلەن ئورتاقلاشتى.\nئۇنى زىيارەت قىلىش ئۈچۈن ئۇلانمىسى بار ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1 $ s بەزى مەزمۇنلارنى سىز بىلەن ئورتاقلاشتى. ئۇنى زىيارەت قىلىش ئۈچۈن ئۇلانمىسى بار ئايرىم ئېلېكترونلۇق خەت تاپشۇرۇۋالغان بولۇشىڭىز كېرەك.",
    "Password to access content shared with you by %1$s" : "سىز بىلەن ئورتاقلاشقان مەزمۇننى زىيارەت قىلىش پارولى%1 $ s",
    "Password to access content" : "مەزمۇننى زىيارەت قىلىدىغان پارول",
    "This item is already shared with this team" : "بۇ تۈر ئاللىقاچان بۇ گۇرۇپپا بىلەن ئورتاقلاشتى",
    "Bring cloud-users closer together." : "بۇلۇت ئىشلەتكۈچىلەرنى يېقىنلاشتۇرۇڭ.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "كوماندىلار كىشىلەرگە ئۆزىنىڭ كىشىلەر / خىزمەتداشلىرى / دوستلىرى توپىنى قۇرالايدۇ.\nئۇ گۇرۇپپىلارنى باشقا ھەرقانداق ئەپ ئارقىلىق ئورتاقلىشىش مەقسىتىدە ئىشلىتىشكە بولىدۇ.",
    "Try again" : "قايتا سىناڭ",
    "No teams found" : "ھېچقانداق كوماندا تېپىلمىدى",
    "Loading…" : "Loading…",
    "No files in here" : "بۇ يەردە ھۆججەت يوق",
    "No entries found in this folder" : "بۇ ھۆججەت قىسقۇچتا ھېچقانداق مەزمۇن تېپىلمىدى",
    "Name" : "ئاتى",
    "Size" : "چوڭلۇقى",
    "Modified" : "ئۆزگەرتكەن",
    "Shared to Circles" : "چەمبىرەككە ئورتاقلاشتى"
},
"nplurals=2; plural=(n != 1);");
